from typing import Dict, List
import requests

from platforms.base import Base


class Sherlock(Base):
    discord_guild_id = '812037309376495636'

    def __init__(self, discord_authorization: str):
        super().__init__(discord_authorization)

    def get_contests(self, filters: List[str]) -> List[Dict]:
        response = requests.get(
            url="https://mainnet-contest.sherlock.xyz/contests")
        body = response.json()
        contests = list(
            map(lambda contest:
                dict(contest,
                     **{
                         'start_timestamp': contest['starts_at'],
                         'end_timestamp': contest['ends_at'],
                         'reward': contest['prize_pool'],
                         'platform': 'Sherlock'
                     }),
                body
                )
        )
        return self.transform(contests, filters)



from typing import Dict, List
import requests
from dateutil import parser as date
from re import sub
from decimal import Decimal

from platforms.base import Base


class Code4rena(Base):
    discord_guild_id = '810916927919620096'

    def __init__(self, discord_authorization: str):
        super().__init__(discord_authorization)

    def get_contests(self, filters: List[str]) -> List[Dict]:
        response = requests.get(
            url="https://code4rena.com/page-data/index/page-data.json")
        body = response.json()
        contests = list(
            map(lambda contest:
                dict(contest,
                     **{
                         'start_timestamp':  date.parse(contest['start_time']).
                         timestamp(),
                         'end_timestamp':  date.parse(contest['end_time']).
                         timestamp(),
                         'reward':  Decimal(sub(r'[^\d.]', '', contest['amount'])),
                         'platform': 'Code4rena'
                     }),
                map(lambda edge: edge['node'], body['result']
                    ['data']['contests']['edges'])
                )
        )
        return self.transform(contests, filters)



from typing import List
import requests


class Channel:
    id: str
    name: str
    users: int


class User:
    id: str
    username: str
    discriminator: int


class Message:
    id: str
    author: User


class Discord():
    def __init__(self, authorization: str):
        self.authorization = authorization

    def get_channels(self, guild_id: str) -> Channel:
        headers = {
            'authorization': self.authorization
        }
        response = requests.get(
            f'https://discord.com/api/guilds/{guild_id}/channels',
            headers=headers
        )
        body = response.json()
        return body

    def get_messages(self, channel_id: str) -> List[Message]:
        headers = {
            'authorization': self.authorization
        }
        response = requests.get(
            f'https://discord.com/api/channels/{channel_id}/messages?limit=100',
            headers=headers
        )
        body = response.json()
        return body

    def get_users_count_from_messages(self, channel_id: str) -> str:
        messages = self.get_messages(channel_id)
        if type(messages) is list:
            users_list = list(map(
                lambda message: message['author']['username'] +
                message['author']['discriminator'], messages))
            counts = {user: users_list.count(user) for user in users_list}
            return str(len(counts))
        else:
            return ''



from setuptools import setup, find_packages

setup(
    name='moonglaive',
    version='0.0.5',
    description='Three-bladed weapon of the night elf Sentinels',
    url='https://github.com/MalfurionWhitehat/moonglaive',
    author='MalfurionWhitehat',
    author_email='MalfurionWhitehat@proton.me',
    license='MIT',
    packages=find_packages(),
    install_requires=[
        'typing',
        'datetime',
        'python-dateutil',
        'python-Levenshtein',
        'fuzzywuzzy',
        'requests',
        'argparse',
        'tabulate'],

    classifiers=[
        'Development Status :: 1 - Planning',
        'Intended Audience :: Science/Research',
        'License :: OSI Approved :: BSD License',
        'Operating System :: POSIX :: Linux',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],
)
